@@ -297,6 +297,27 @@ class configpath(configitem):
         return os.path.expanduser(s)
 
 
+class confignetworklocation(configitem):
+
+    def _parselocation(self, s):
+        if ":" in s:
+            # address:port
+            name, port = s.split(":")
+            port = int(port)
+            return name, port
+        else:
+            return os.path.expanduser(s)
+
+    def _check(self, s):
+        try:
+            self._parselocation(s)
+        except:
+            raise ConfigError("Excepting address:port or filename, got '%s'" % s)            
+
+    def _convert(self, s):
+        return self._parselocation(s)
+ 
+
 class configre(configitem):
     def _convert(self, s):
         return re.compile(s)
@@ -371,8 +392,7 @@ class database(configsection):
         tags_removeaccents = configboolean("true")
         autoregisterer = configboolean("on")
         playingstatslength = configint("100")
-        server = configstring("")
-        port = configint("1972")
+        networklocation = confignetworklocation("localhost:1972")
 
 class mixer(configsection):
     device = configpath("/dev/mixer")
@@ -380,9 +400,9 @@ class mixer(configsection):
     stepsize = configint("5")
 
 class network(configsection):
-    enableserver = configboolean("false")
-    server = configstring("")
     socketfile = configstring("~/.pytone/pytonectl")
+    enableserver = configboolean("false")
+    bind = configstring("")
     port = configint("1972")
 
 class player(configsection):
@@ -407,8 +427,7 @@ class player(configsection):
         cmdline = configstring("/usr/bin/mpg321 --skip-printing-frames=5 -a /dev/dsp")
 
         # only for remote player
-        server = configstring("")
-        port = configint("1972")
+        networklocation = confignetworklocation("localhost:1972")
 
     class secondary(configsection):
         type = configalternatives("off", ["internal", "xmms", "mpg123", "off"])
@@ -598,6 +617,7 @@ class keybindings(configsection):
         showhelp = configkeys("?")
         showlog = configkeys("!")
         showiteminfolong = configkeys("=")
+        toggleiteminfowindow = configkeys("ctrl-v")
         volumeup = configkeys(")")
         volumedown = configkeys("(")
 
@@ -825,10 +845,10 @@ def processcommandline():
 
 
 def checkoptions():
-    if network.enableserver and network.server:
-        usage()
-        print "Error: cannot run both as server and as client"
-        sys.exit(2)
+    #if network.enableserver and network.server:
+    #    usage()
+    #    print "Error: cannot run both as server and as client"
+    #    sys.exit(2)
 
 
     # check database options
