@@ -23,6 +23,10 @@ import dbitem, metadata
 import events, hub, requests
 import helper
 
+# We import the _genrandomchoice function used in the songdb module.
+# Maybe we should instead put it in a separate module
+from services.songdb import _genrandomchoice
+
 
 class item:
     """ base class for various items presentend in the database and
@@ -244,7 +248,7 @@ class song(item):
         d.update(self.song.__dict__)
         d.update(adddict)
         d["minutes"], d["seconds"] = divmod(d["length"], 60)
-        d["length"] = "%d:%2d" % (d["minutes"], d["seconds"])
+        d["length"] = "%d:%02d" % (d["minutes"], d["seconds"])
 
         if safe:
             allowedchars = string.letters + string.digits + " :"
