@@ -43,7 +43,11 @@ class playerwin(window.window):
         window.window.__init__(self, screen, h, w, y, x,
                                config.colors.playerwindow,
                                _("Playback Info"), border)
-
+	try:
+            self.playerinfofd = open(self.playerinfofile, "w")
+        except IOError, e:
+            log.error(_("error '%s' occured during write to playerinfofile") % e)
+            self.playerinfofd = None
         # we don't want to have the focus
         self.panel.bottom()
 
@@ -102,18 +106,18 @@ class playerwin(window.window):
             self.update()
 
             # update player info file, if configured
-            if self.playerinfofile:
+            if self.playerinfofd and self.song:
                 try:
-                    f = open(config.general.playerinfofile, "w")
-                    if self.song:
-                        f.write("%s - %s (%s/%s)\n"  % ( self.song.artist,
-                                                         self.song.title,
-                                                         formattime(self.time),
-                                                         formattime(self.song.length)))
-                    f.close()
+                    self.playerinfofd.seek(0)
+                    info = "%s - %s (%s/%s)\n"  % ( self.song.artist,
+                                                    self.song.title,
+                                                    formattime(self.time),
+                                                    formattime(self.song.length))
+                    self.playerinfofd.write(info)
+                    self.playerinfofd.truncate(len(info))
                 except IOError, e:
                     log.error(_("error '%s' occured during write to playerinfofile") % e)
-                    self.playerinfofile = None
+                    self.playerinfofd = None
                     
 
     def keypressed(self, event):
