@@ -36,5 +36,5 @@ class plugin:
 class threadedplugin(service.service, plugin):
 
     def __init__(self, channel, config, mainscreen):
-        service.service.__init__(self, self.__class.__.__name__)
+        service.service.__init__(self, self.__class__.__name__)
         plugin.__init__(self, channel, config, mainscreen)
