@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003, 2004 Jrg Lehmann <joerg@luga.de>
+# Copyright (C) 2002, 2003, 2004, 2005 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -18,7 +18,7 @@
 # along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import curses, os, os.path, signal, sys
+import curses, os, os.path, signal, imp, sys
 
 ##############################################################################
 # gettext initialization.
@@ -125,7 +125,7 @@ try:
     # network service
     if config.network.enableserver:
         import network
-        network.tcpserver("localhost", config.network.port).start()
+        network.tcpserver(config.network.bind, config.network.port).start()
     if config.network.socketfile:
         import network
         network.unixserver(os.path.expanduser(config.network.socketfile)).start()
@@ -140,24 +140,29 @@ try:
     # The result goees into a list of tuples (pluginmodule, pluginconfig).
     plugins = []
 
-    # Extend search path for plugins
-    sys.path[0:0] = [os.path.expanduser('~/.pytone')]
+    userpluginpath = os.path.expanduser("~/.pytone/plugins/")
+    cwd = os.path.abspath(os.path.dirname(sys.argv[0]))
+    globalpluginpath = os.path.join(cwd, "plugins")
+    pluginpath = [userpluginpath, globalpluginpath]
 
     for name in config.general.plugins:
-        # import plugin module, taking into account that __import__ returns
-        # the top-level package, when using it with a dotted path
-        pluginmodule = getattr(__import__("plugins.%s" % name), name)
-
-        # process configuration of plugin
-        pluginconfig = pluginmodule.config
-        if pluginconfig is not None:
-            config.readconfigsection("plugin.%s" % name, pluginconfig)
-            config.finishconfigsection(pluginconfig)
-        pluginconfig = pluginconfig()
-        plugins.append((pluginmodule, pluginconfig))
-
-    # Set sys.path back to its original state
-    del sys.path[0]
+        try:
+            # We use imp.find_module to narrow down the plugin search path
+            # to the two possible locations. Setting sys.path correspondingly
+            # would not work, however, since then the plugin could not
+            # import its needed modules. 
+            fp, pathname, description = imp.find_module(name, pluginpath)
+            pluginmodule = imp.load_module(name, fp, pathname, description)
+            # 
+            # process configuration of plugin
+            pluginconfig = pluginmodule.config
+            if pluginconfig is not None:
+                config.readconfigsection("plugin.%s" % name, pluginconfig)
+                config.finishconfigsection(pluginconfig)
+            pluginconfig = pluginconfig()
+            plugins.append((pluginmodule, pluginconfig))
+        except Exception, e:
+             log.error(_("Cannot load plugin '%s': %s" % (name, e)))
 except:
     # if something goes wrong, shutdown all already running services
     hub.notify(events.quit(), 100)
