@@ -393,7 +393,9 @@ class playlist(service.service):
                         break
                 else:
                     self.append(newitem)
-                hub.notify(events.playerplaysong(self.playerid, self._playnext()))
+                self._playitem(newitem)
+                self._updateplaystarttimes()
+                hub.notify(events.playerplaysong(self.playerid, song))
                 self.notifyplaylistchanged()
 
     def playlistdeletesong(self, event):
