@@ -120,7 +120,6 @@ class songdbmanager(service.service):
         # we are a database service provider...
         self.channel.supply(requests.dbrequestsingle, self.dbrequestsingle)
         self.channel.supply(requests.dbrequestsongs, self.dbrequestsongs)
-        self.channel.supply(requests.getlastplayedsongs, self.getlastplayedsongs)
         self.channel.supply(requests.dbrequestlist, self.dbrequestlist)
         self.channel.supply(requests.getnumberofsongs, self.getnumberofsongs)
         self.channel.supply(requests.getnumberofalbums, self.getnumberofalbums)
@@ -148,7 +147,7 @@ class songdbmanager(service.service):
             songdb = songdbs.local.songdb(id, config, self.songdbhub)
         elif type=="remote":
             import songdbs.remote
-            songdb = songdbs.remote.songdb(id, config.server, config.port, self.songdbhub)
+            songdb = songdbs.remote.songdb(id, config.networklocation, self.songdbhub)
 
         self.songdbids.append(id)
         songdb.setName("song database thread (id=%s)" % id)
@@ -260,10 +259,10 @@ class songdbmanager(service.service):
         self.songdbhub.notify(event)
 
     # request handlers
-    
+
     def dbrequestsingle(self, request):
         if request.songdbid not in self.songdbids:
-            log.error("songdbmanager: invalid songdbid for database request")
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
             return
 
         result = self.songdbhub.request(request)
@@ -287,60 +286,49 @@ class songdbmanager(service.service):
         nrequest = copy.copy(request)
         # we do not care about the random choice flag, this is done by the method decorator
         nrequest.random = False
+        # also reset the sort and wrapper function as otherwise
+        # sending over the network (which requires pickling the
+        # request) fails
+        nrequest.sort = False
+        nrequest.wrapperfunc = False
         if request.songdbid is None:
             resulthash = {}
             for songdbid in self.songdbids:
                 nrequest.songdbid = songdbid
                 # Query the songs in the database songdbid via dbrequestsongs to cache
-                # the result. For removing duplicates, we have to use the original
-                # dbitem.song stored in the item.song instances.
-                for song in self.dbrequestsongs(nrequest):
-                    resulthash[song.song] = song
-            return resulthash.values()
+                # the result.
+                # Note that in the case of getlastplayedsongs requests, we cheat
+                # a little bit, since then the result of the database request is a tuple
+                # (playingtime, dbsong). Correspondingly, wrapperfunc has to deal
+                # with such tuples instead of with the dbsongs themselves.
+                for dbsong in self.dbrequestsongs(nrequest):
+                    resulthash[dbsong] = songdbid
+            if request.wrapperfunc:
+                return [request.wrapperfunc(dbsong, songdbid) for dbsong, songdbid in resulthash.items()]
+            else:
+                return resulthash.values()
         elif request.songdbid not in self.songdbids:
-            log.error("songdbmanager: invalid songdbid for database request")
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
+            return
         else:
             dbsongs = self.songdbhub.request(nrequest)
-            return map(lambda asong, songdbid=request.songdbid: item.song(songdbid, asong), dbsongs)
+            if request.wrapperfunc:
+                return [request.wrapperfunc(dbsong, request.songdbid) for dbsong in dbsongs]
+            else:
+                return dbsongs
     dbrequestsongs = selectrandom(cacheresult(sortresult(dbrequestsongs)))
 
-    # the list of last played songs has to be treated separately, because here
-    # songs may actually appear more than once. Thus, we must not remove
-    # duplicates here. Note that we cheat a little bit here, since the
-    # results of the getlastplayedsongs request from the database and the database managers
-    # differ in that the former ones are lists of tuples (dbitem.song, playingtime), while the
-    # latter ones are just lists of item.song instances. 
-    def getlastplayedsongs(self, request):
+    def dbrequestlist(self, request):
         # make a copy of the original request, because we will subsequently modify it
         nrequest = copy.copy(request)
-        # we do not care about the random choice flag, this is done by the method decorator
-        nrequest.random = False
-        if request.songdbid is None:
-            result = []
-            for songdbid in self.songdbids:
-                nrequest.songdbid = songdbid
-                # Query the songs in the database songdbid via dbrequestsongs to cache
-                # the result. 
-                for song in self.getlastplayedsongs(nrequest):
-                    result.append(song)
-            return result
-        elif request.songdbid not in self.songdbids:
-            log.error("songdbmanager: invalid songdbid for database request")
-        else:
-            return [item.song(request.songdbid, asong, playingtime)
-                    for asong, playingtime in self.songdbhub.request(nrequest)]
-    getlastplayedsongs = selectrandom(cacheresult(sortresult(getlastplayedsongs)))
+        # we do not want to wrap and sort the intermediate results
+        nrequest.wrapperfunc = None
+        nrequest.sort = False
 
-    def dbrequestlist(self, request):
         if request.songdbid is None:
-            # make a copy of the original request, because we will subsequently modify it
-            nrequest = copy.copy(request)
             resulthash = {}
             for songdbid in self.songdbids:
                 nrequest.songdbid = songdbid
-                # we do not want to wrap and sort the intermediate results
-                nrequest.wrapperfunc = None
-                nrequest.sort = None
                 for result in self.dbrequestlist(nrequest):
                     resulthash[result] = songdbid
             if request.wrapperfunc is not None:
@@ -348,9 +336,13 @@ class songdbmanager(service.service):
             else:
                 return resulthash.keys()
         elif request.songdbid not in self.songdbids:
-            log.error("songdbmanager: invalid songdbid for database request")
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
         else:
-            result = self.songdbhub.request(request)
+            # use nrequest here instead of request in order to not
+            # send wrapperfunc and sort to database (this fails when
+            # using a network channel, since we cannot pickle these
+            # objects)
+            result = self.songdbhub.request(nrequest)
             if request.wrapperfunc is not None:
                 return [request.wrapperfunc(item, request.songdbid) for item in result]
             else:
@@ -366,7 +358,7 @@ class songdbmanager(service.service):
         executed directly. Otherwise, the length of the result of listrequest
         is returned. """
         if request.songdbid is not None and request.songdbid not in self.songdbids:
-            log.error("songdbmanager: invalid songdbid for database request")
+            log.error("songdbmanager: invalid songdbid '%s' for database request" % request.songdbid)
         elif request.songdbid is None or requestkwargs:
             if issubclass(listrequest, requests.dbrequestlist):
                 return len(self.dbrequestlist(listrequest(songdbid=None, **requestkwargs)))
