@@ -136,7 +136,7 @@ class window:
         """ return open ends of border as list of tuples (y, x, direction)
         where direction is one of "left", "right" , "up" or "down"
         """
-        
+
         borderends = []
         if self.hastopborder() and not self.hasleftborder():
             borderends.append((self.y, self.x-1, "left"))
@@ -157,7 +157,7 @@ class window:
             borderends.append((self.y+self.h+1, self.x, "down"))
         if self.hasrightborder() and not self.hasbottomborder():
             borderends.append((self.y+self.h+1, self.x+self.w-1, "down"))
-            
+
         return borderends
 
     def connectborderends(self, borderends):
@@ -256,6 +256,9 @@ class window:
         """ bring window to top"""
         try:
             self.panel.top()
+            # The following call fixes the redrawing problem when switching between
+            # the filelist and the playlist window reported by Dag Wieers.
+            curses.panel.update_panels()
         except:
             pass
         else:
@@ -290,7 +293,7 @@ class window:
     def stdscrtowin(self, y, x):
         begy, begx = self.win.getbegyx()
         return y-begy, x-begx
-    
+
     def update(self):
         if self.title and self.h>=2:
             if self.hasfocus():
@@ -308,7 +311,7 @@ class window:
                 titleattr = self.colors.title
 
             # draw configured borders
-            
+
             if self.hastopborder():
                 self.hline(0, self.ix, curses.ACS_HLINE, self.iw, attr)
                 # self.win.border(0, 0, topborder)
